@@ -25,33 +25,35 @@
 
 #include <sys/types.h>
 #include <gtk/gtk.h>
+#include <camel/camel-exception.h>
+#include <camel/camel-folder.h>
+#include <camel/camel-internet-address.h>
+#include <camel/camel-mime-message.h>
+#include <camel/camel-mime-part.h>
+#include <camel/camel-stream.h>
 
-#include <mail/em-format.h>
+#include <mail/e-mail-reader.h>
+#include <mail/em-folder-tree.h>
 
 G_BEGIN_DECLS
 
-gboolean em_utils_prompt_user(GtkWindow *parent, const gchar *promptkey, const gchar *tag, const gchar *arg0, ...);
+struct _EMFormat;
+
+gboolean em_utils_ask_open_many (GtkWindow *parent, gint how_many);
+gboolean em_utils_prompt_user(GtkWindow *parent, const gchar *promptkey, const gchar *tag, ...);
 
 GPtrArray *em_utils_uids_copy (GPtrArray *uids);
 void em_utils_uids_free (GPtrArray *uids);
 
-gboolean em_utils_configure_account (GtkWidget *parent);
-gboolean em_utils_check_user_can_send_mail (GtkWidget *parent);
+gboolean em_utils_check_user_can_send_mail (void);
 
 void em_utils_edit_filters (GtkWidget *parent);
 void em_filename_make_safe (gchar *string);
 void em_utils_edit_vfolders (GtkWidget *parent);
 
-void em_utils_save_part(GtkWidget *parent, const gchar *prompt, CamelMimePart *part);
-gboolean em_utils_save_part_to_file(GtkWidget *parent, const gchar *filename, CamelMimePart *part);
-void em_utils_save_messages (GtkWidget *parent, CamelFolder *folder, GPtrArray *uids);
-
-void em_utils_add_address(GtkWidget *parent, const gchar *email);
-void em_utils_add_vcard(GtkWidget *parent, const gchar *vcard);
-
-void em_utils_flag_for_followup (GtkWidget *parent, CamelFolder *folder, GPtrArray *uids);
-void em_utils_flag_for_followup_clear (GtkWidget *parent, CamelFolder *folder, GPtrArray *uids);
-void em_utils_flag_for_followup_completed (GtkWidget *parent, CamelFolder *folder, GPtrArray *uids);
+void em_utils_flag_for_followup (EMailReader *reader, CamelFolder *folder, GPtrArray *uids);
+void em_utils_flag_for_followup_clear (GtkWindow *parent, CamelFolder *folder, GPtrArray *uids);
+void em_utils_flag_for_followup_completed (GtkWindow *parent, CamelFolder *folder, GPtrArray *uids);
 
 /* This stuff that follows probably doesn't belong here, then again, the stuff above probably belongs elsewhere */
 
@@ -65,20 +67,16 @@ void em_utils_selection_set_urilist(GtkSelectionData *data, CamelFolder *folder,
 void em_utils_selection_get_urilist(GtkSelectionData *data, CamelFolder *folder);
 
 gchar *em_utils_temp_save_part(GtkWidget *parent, CamelMimePart *part, gboolean mode);
-void em_utils_save_parts (GtkWidget *parent, const gchar *prompt, GSList * parts);
 
 gboolean em_utils_folder_is_drafts(CamelFolder *folder, const gchar *uri);
 gboolean em_utils_folder_is_templates(CamelFolder *folder, const gchar *uri);
 gboolean em_utils_folder_is_sent(CamelFolder *folder, const gchar *uri);
 gboolean em_utils_folder_is_outbox(CamelFolder *folder, const gchar *uri);
 
-void em_utils_adjustment_page(GtkAdjustment *adj, gboolean down);
-
 gchar *em_utils_get_proxy_uri (const gchar *uri);
 
 /* FIXME: should this have an override charset? */
-gchar *em_utils_part_to_html(CamelMimePart *part, gssize *len, EMFormat *source);
-gchar *em_utils_message_to_html(CamelMimeMessage *msg, const gchar *credits, guint32 flags, gssize *len, EMFormat *source, const gchar *append);
+gchar *em_utils_message_to_html (CamelMimeMessage *msg, const gchar *credits, guint32 flags, gssize *len, struct _EMFormat *source, const gchar *append, guint32 *validity_found);
 
 void em_utils_expunge_folder (GtkWidget *parent, CamelFolder *folder);
 void em_utils_empty_trash (GtkWidget *parent);
@@ -98,15 +96,22 @@ void em_utils_show_info_silent (GtkWidget *widget);
 gboolean em_utils_in_addressbook (CamelInternetAddress *addr, gboolean local_only);
 CamelMimePart *em_utils_contact_photo (CamelInternetAddress *addr, gboolean local);
 
-const gchar *em_utils_snoop_type(CamelMimePart *part);
-
 /* clears flag 'get_password_canceled' at every known accounts, so if needed, get_password will show dialog */
 void em_utils_clear_get_password_canceled_accounts_flag (void);
 
+/* Unescapes &amp; back to a real & in URIs */
+gchar *em_utils_url_unescape_amp (const gchar *url);
+
+GHashTable * em_utils_generate_account_hash (void);
+struct _EAccount *em_utils_guess_account (CamelMimeMessage *message, CamelFolder *folder);
+struct _EAccount *em_utils_guess_account_with_recipients (CamelMimeMessage *message, CamelFolder *folder);
+
 void emu_remove_from_mail_cache (const GSList *addresses);
 void emu_remove_from_mail_cache_1 (const gchar *address);
 void emu_free_mail_cache (void);
 
+void emu_restore_folder_tree_state (EMFolderTree *folder_tree);
+
 G_END_DECLS
 
 #endif /* __EM_UTILS_H__ */
